@@ -2,7 +2,6 @@
 
 #include <QApplication>
 #include <QColor>
-// #include <QDebug>
 #include <QSettings>
 
 #include "dsosettings.h"
@@ -10,9 +9,13 @@
 
 /// \brief Set the number of channels.
 /// \param channels The new channel count, that will be applied to lists.
-DsoSettings::DsoSettings( const Dso::ControlSpecification *deviceSpecification ) : deviceSpecification( deviceSpecification ) {
+DsoSettings::DsoSettings( const ScopeDevice *scopeDevice, bool resetSettings )
+    : deviceName( scopeDevice->getModel()->name ), deviceID( scopeDevice->getSerialNumber() ),
+      deviceFW( scopeDevice->getFwVersion() ), deviceSpecification( scopeDevice->getModel()->spec() ),
+      resetSettings( resetSettings ) {
     // Add new channels to the list
-    unsigned char trace_hue[] = {60, 240, 0, 120}; // yellow, blue, red, green
+    int voltage_hue[] = { 60, 210, 0, 120 };   // yellow, lightblue, red, green
+    int spectrum_hue[] = { 30, 240, 330, 90 }; // orange, blue, purple, green
     unsigned index = 0;
     scope.hasACcoupling = deviceSpecification->hasACcoupling;
     while ( scope.spectrum.size() < deviceSpecification->channels ) {
@@ -25,12 +28,11 @@ DsoSettings::DsoSettings( const Dso::ControlSpecification *deviceSpecification )
         DsoSettingsScopeVoltage newVoltage;
         newVoltage.name = tr( "CH%1" ).arg( index + 1 );
         scope.voltage.push_back( newVoltage );
-
-        view.screen.voltage.push_back( QColor::fromHsv( trace_hue[ index ], 0xff, 0xff ) );
-        view.screen.spectrum.push_back( QColor::fromHsv( trace_hue[ index ] - 30, 0xff, 0xff ) );
+        view.screen.voltage.push_back( QColor::fromHsv( voltage_hue[ index ], 0xff, 0xff ) );
+        view.screen.spectrum.push_back( QColor::fromHsv( spectrum_hue[ index ], 0xff, 0xff ) );
         view.print.voltage.push_back( view.screen.voltage.back().darker() );
         view.print.spectrum.push_back( view.screen.spectrum.back().darker() );
-        if ( ++index >= sizeof trace_hue )
+        if ( ++index >= sizeof voltage_hue )
             index = 0;
     }
 
@@ -48,6 +50,15 @@ DsoSettings::DsoSettings( const Dso::ControlSpecification *deviceSpecification )
     view.print.voltage.push_back( QColor::fromHsv( 300, 0xff, 0xff ) );
     view.print.spectrum.push_back( QColor::fromHsv( 320, 0xff, 0xff ) );
 
+    // create an unique storage for this device based on device name and serial number
+    // individual device settings location:
+    // Linux, Unix: $HOME/.config/OpenHantek/<deviceName>_<deviceID>.conf
+    // macOS:       $HOME/Library/Preferences/org.openhantek.<deviceName>_<deviceID>.plist
+    // Windows:     HKEY_CURRENT_USER\Software\OpenHantek\<deviceName>_<deviceID>
+    // more info:   https://doc.qt.io/qt-5/qsettings.html#platform-specific-notes
+    storeSettings =
+        std::unique_ptr< QSettings >( new QSettings( QCoreApplication::organizationName(), deviceName + "_" + deviceID ) );
+    // and get the persistent settings
     load();
 }
 
@@ -63,11 +74,16 @@ bool DsoSettings::setFilename( const QString &filename ) {
 }
 
 
+// load the persistent scope settings
+// called by "DsoSettings::DsoSettings" and explicitely by "ui->actionOpen"
 void DsoSettings::load() {
+    if ( scope.verboseLevel > 1 )
+        qDebug() << " DsoSettings::load()";
     // Start with default configuration?
-    if ( storeSettings->value( "configuration/version", 0 ).toUInt() < CONFIG_VERSION ) {
+    if ( resetSettings || storeSettings->value( "configuration/version", 0 ).toUInt() < CONFIG_VERSION ) {
         // incompatible change or config reset by user
         storeSettings->clear(); // start with a clean config storage
+        QSettings().clear();    // and a clean global storage
         setDefaultConfig();
         return;
     }
@@ -106,7 +122,7 @@ void DsoSettings::load() {
     if ( storeSettings->contains( "mode" ) )
         scope.trigger.mode = Dso::TriggerMode( storeSettings->value( "mode" ).toUInt() );
     if ( storeSettings->contains( "position" ) )
-        scope.trigger.offset = storeSettings->value( "position" ).toDouble();
+        scope.trigger.position = storeSettings->value( "position" ).toDouble();
     if ( storeSettings->contains( "slope" ) )
         scope.trigger.slope = Dso::Slope( storeSettings->value( "slope" ).toUInt() );
     if ( storeSettings->contains( "source" ) )
@@ -140,7 +156,8 @@ void DsoSettings::load() {
         storeSettings->endGroup(); // spectrum%1
     }
     // Voltage
-    bool defaultConfig = deviceSpecification->isDemoDevice; // use default channel setting in demo mode
+    bool defaultConfig = false;
+    // defaultConfig = deviceSpecification->isDemoDevice; // use default channel setting in demo mode
     if ( storeSettings->contains( "hasACmodification" ) )
         scope.hasACmodification = storeSettings->value( "hasACmodification" ).toBool();
     for ( ChannelID channel = 0; channel < scope.voltage.size(); ++channel ) {
@@ -267,12 +284,29 @@ void DsoSettings::load() {
 }
 
 
+// save the persistent scope settings
+// called by "MainWindow::closeEvent" and explicitely by "ui->actionSave" and "ui->actionSave_as"
 void DsoSettings::save() {
     // Use default configuration after restart?
     if ( 0 == configVersion ) {
         storeSettings->clear();
+        if ( scope.verboseLevel > 1 )
+            qDebug() << " DsoSettings::save() storeSettings->clear()";
         return;
+    } else { // save fontSize as global setting
+        QSettings().setValue( "view/fontSize", view.fontSize );
     }
+    if ( scope.verboseLevel > 1 )
+        qDebug() << " DsoSettings::save()" << deviceName << deviceID;
+    // now store individual device values
+
+    //  Device ID (helps to identify the connection of a "Save as" file with a specific device)
+    storeSettings->beginGroup( "DeviceID" );
+    storeSettings->setValue( "Model", deviceName );
+    storeSettings->setValue( "SerialNumber", deviceID );
+    storeSettings->endGroup(); // DeviceID
+
+    // Configuration settings
     storeSettings->beginGroup( "configuration" );
     storeSettings->setValue( "version", configVersion );
     storeSettings->setValue( "alwaysSave", alwaysSave );
@@ -296,7 +330,7 @@ void DsoSettings::save() {
     // Trigger
     storeSettings->beginGroup( "trigger" );
     storeSettings->setValue( "mode", unsigned( scope.trigger.mode ) );
-    storeSettings->setValue( "position", scope.trigger.offset );
+    storeSettings->setValue( "position", scope.trigger.position );
     storeSettings->setValue( "slope", unsigned( scope.trigger.slope ) );
     storeSettings->setValue( "source", scope.trigger.source );
     storeSettings->setValue( "smooth", scope.trigger.smooth );
@@ -358,7 +392,6 @@ void DsoSettings::save() {
     // View
     storeSettings->beginGroup( "view" );
     // Colors
-
     storeSettings->beginGroup( "color" );
     DsoSettingsColorValues *colors;
     for ( int mode = 0; mode < 2; ++mode ) {
@@ -388,12 +421,14 @@ void DsoSettings::save() {
     storeSettings->setValue( "histogram", scope.histogram );
     storeSettings->setValue( "digitalPhosphor", view.digitalPhosphor );
     storeSettings->setValue( "interpolation", view.interpolation );
+    // storeSettings->setValue( "fontSize", view.fontSize );
     storeSettings->setValue( "printerColorImages", view.printerColorImages );
     storeSettings->setValue( "zoom", view.zoom );
     storeSettings->setValue( "cursorGridPosition", view.cursorGridPosition );
     storeSettings->setValue( "cursorsVisible", view.cursorsVisible );
     storeSettings->endGroup(); // view
 
+    // Program window geometry and state
     storeSettings->beginGroup( "window" );
     storeSettings->setValue( "geometry", mainWindowGeometry );
     storeSettings->setValue( "state", mainWindowState );
