@@ -6,6 +6,7 @@
 #include <QFileDialog>
 #include <QGridLayout>
 #include <QLabel>
+#include <QScreen>
 #include <QSignalBlocker>
 #include <QTimer>
 
@@ -30,20 +31,28 @@ DsoWidget::DsoWidget( DsoSettingsScope *scope, DsoSettingsView *view, const Dso:
     : QWidget( parent ), scope( scope ), view( view ), spec( spec ), mainScope( GlScope::createNormal( scope, view ) ),
       zoomScope( GlScope::createZoomed( scope, view ) ) {
 
+    if ( scope->verboseLevel > 1 )
+        qDebug() << " DsoWidget::DsoWidget()";
+
+    // get the primary screen size for further use - e.g. graphgenerator.cpp
+    QSize screenSize = QGuiApplication::primaryScreen()->size();
+    view->screenHeight = unsigned( screenSize.height() );
+    view->screenWidth = unsigned( screenSize.width() );
+
     // Palette for this widget
     QPalette palette;
-    palette.setColor( QPalette::Background, view->colors->background );
+    palette.setColor( QPalette::Window, view->colors->background );
     palette.setColor( QPalette::WindowText, view->colors->text );
 
     setupSliders( mainSliders );
     setupSliders( zoomSliders );
 
-    connect( mainScope, &GlScope::markerMoved, [this]( unsigned cursorIndex, unsigned marker ) {
+    connect( mainScope, &GlScope::markerMoved, [ this ]( unsigned cursorIndex, unsigned marker ) {
         mainSliders.markerSlider->setValue( int( marker ), this->scope->getMarker( marker ) );
         mainScope->updateCursor( cursorIndex );
         zoomScope->updateCursor( cursorIndex );
     } );
-    connect( zoomScope, &GlScope::markerMoved, [this]( unsigned cursorIndex ) {
+    connect( zoomScope, &GlScope::markerMoved, [ this ]( unsigned cursorIndex ) {
         mainScope->updateCursor( cursorIndex );
         zoomScope->updateCursor( cursorIndex );
     } );
@@ -102,60 +111,61 @@ DsoWidget::DsoWidget( DsoSettingsScope *scope, DsoSettingsView *view, const Dso:
     markerLayout->addWidget( markerFrequencybaseLabel, 1 );
 
     // The table for the measurements at screen bottom
-    QPalette tablePalette = palette;
     measurementLayout = new QGridLayout();
-    measurementLayout->setColumnMinimumWidth( 0, 80 ); // Channel
+    measurementLayout->setColumnMinimumWidth( 0, 50 ); // Channel
     measurementLayout->setColumnMinimumWidth( 1, 30 ); // Coupling or Mode
     measurementLayout->setColumnStretch( 2, 3 );       // Voltage amplitude
     measurementLayout->setColumnStretch( 3, 3 );       // Spectrum magnitude
     measurementLayout->setColumnStretch( 4, 3 );       // Vpp
     measurementLayout->setColumnStretch( 5, 3 );       // VDC
     measurementLayout->setColumnStretch( 6, 3 );       // Vac
-    measurementLayout->setColumnStretch( 7, 3 );       // Vrms
+    measurementLayout->setColumnStretch( 7, 4 );       // Vrms
     measurementLayout->setColumnStretch( 8, 3 );       // dB
     measurementLayout->setColumnStretch( 9, 3 );       // Power
     measurementLayout->setColumnStretch( 10, 2 );      // THD
     measurementLayout->setColumnStretch( 11, 3 );      // f
     for ( ChannelID channel = 0; channel < scope->voltage.size(); ++channel ) {
-        tablePalette.setColor( QPalette::WindowText, view->colors->voltage[ channel ] );
+        QPalette voltagePalette = palette;
+        QPalette spectrumPalette = palette;
+        voltagePalette.setColor( QPalette::WindowText, view->colors->voltage[ channel ] );
+        spectrumPalette.setColor( QPalette::WindowText, view->colors->spectrum[ channel ] );
         measurementNameLabel.push_back( new QLabel( scope->voltage[ channel ].name ) );
-        measurementNameLabel[ channel ]->setAlignment( Qt::AlignCenter );
-        measurementNameLabel[ channel ]->setPalette( tablePalette );
+        measurementNameLabel[ channel ]->setAlignment( Qt::AlignLeft );
+        measurementNameLabel[ channel ]->setPalette( voltagePalette );
         measurementNameLabel[ channel ]->setAutoFillBackground( true );
         measurementMiscLabel.push_back( new QLabel() );
-        measurementMiscLabel[ channel ]->setAlignment( Qt::AlignLeft );
-        measurementMiscLabel[ channel ]->setPalette( tablePalette );
+        measurementMiscLabel[ channel ]->setAlignment( Qt::AlignHCenter );
+        measurementMiscLabel[ channel ]->setPalette( voltagePalette );
         measurementGainLabel.push_back( new QLabel() );
         measurementGainLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementGainLabel[ channel ]->setPalette( tablePalette );
-        tablePalette.setColor( QPalette::WindowText, view->colors->spectrum[ channel ] );
+        measurementGainLabel[ channel ]->setPalette( voltagePalette );
         measurementMagnitudeLabel.push_back( new QLabel() );
         measurementMagnitudeLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementMagnitudeLabel[ channel ]->setPalette( tablePalette );
+        measurementMagnitudeLabel[ channel ]->setPalette( spectrumPalette );
         measurementVppLabel.push_back( new QLabel() );
         measurementVppLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementVppLabel[ channel ]->setPalette( palette );
+        measurementVppLabel[ channel ]->setPalette( voltagePalette );
         measurementDCLabel.push_back( new QLabel() );
         measurementDCLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementDCLabel[ channel ]->setPalette( palette );
+        measurementDCLabel[ channel ]->setPalette( voltagePalette );
         measurementACLabel.push_back( new QLabel() );
         measurementACLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementACLabel[ channel ]->setPalette( palette );
+        measurementACLabel[ channel ]->setPalette( voltagePalette );
         measurementRMSLabel.push_back( new QLabel() );
         measurementRMSLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementRMSLabel[ channel ]->setPalette( palette );
+        measurementRMSLabel[ channel ]->setPalette( voltagePalette );
         measurementdBLabel.push_back( new QLabel() );
         measurementdBLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementdBLabel[ channel ]->setPalette( palette );
+        measurementdBLabel[ channel ]->setPalette( voltagePalette );
         measurementRMSPowerLabel.push_back( new QLabel() );
         measurementRMSPowerLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementRMSPowerLabel[ channel ]->setPalette( palette );
+        measurementRMSPowerLabel[ channel ]->setPalette( voltagePalette );
         measurementTHDLabel.push_back( new QLabel() );
         measurementTHDLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementTHDLabel[ channel ]->setPalette( palette );
+        measurementTHDLabel[ channel ]->setPalette( voltagePalette );
         measurementFrequencyLabel.push_back( new QLabel() );
         measurementFrequencyLabel[ channel ]->setAlignment( Qt::AlignRight );
-        measurementFrequencyLabel[ channel ]->setPalette( palette );
+        measurementFrequencyLabel[ channel ]->setPalette( voltagePalette );
         setMeasurementVisible( channel );
         int iii = 0;
         measurementLayout->addWidget( measurementNameLabel[ channel ], int( channel ), iii++ );
@@ -190,11 +200,11 @@ DsoWidget::DsoWidget( DsoSettingsScope *scope, DsoSettingsView *view, const Dso:
     }
     cursorDataGrid->selectItem( 0 );
 
-    connect( cursorDataGrid, &DataGrid::itemSelected, [this]( unsigned index ) {
+    connect( cursorDataGrid, &DataGrid::itemSelected, [ this ]( unsigned index ) {
         mainScope->cursorSelected( index );
         zoomScope->cursorSelected( index );
     } );
-    connect( cursorDataGrid, &DataGrid::itemUpdated, [this, scope]( unsigned index ) {
+    connect( cursorDataGrid, &DataGrid::itemUpdated, [ this, scope ]( unsigned index ) {
         unsigned channelCount = scope->countChannels();
         if ( 0 < index && index < channelCount + 1 ) {
             ChannelID channel = index - 1;
@@ -267,13 +277,14 @@ DsoWidget::DsoWidget( DsoSettingsScope *scope, DsoSettingsView *view, const Dso:
     ++row; // end 5x4 box
     // Separator and embedded measurementLayout
     ++row;
+    // display channel measurements on bottom of scope
     mainLayout->addLayout( measurementLayout, row, 1, 1, 5 );
 
     updateCursorGrid( view->cursorsVisible );
 
     // The widget itself
     setPalette( palette );
-    setBackgroundRole( QPalette::Background );
+    setBackgroundRole( QPalette::Window );
     setAutoFillBackground( true );
     setLayout( mainLayout );
 
@@ -282,24 +293,24 @@ DsoWidget::DsoWidget( DsoSettingsScope *scope, DsoSettingsView *view, const Dso:
     connect( zoomSliders.voltageOffsetSlider, &LevelSlider::valueChanged, this, &DsoWidget::updateOffset );
 
     connect( mainSliders.triggerPositionSlider, &LevelSlider::valueChanged,
-             [this]( int index, double value ) { updateTriggerOffset( index, value, true ); } );
+             [ this ]( int index, double value ) { updateTriggerPosition( index, value, true ); } );
     connect( zoomSliders.triggerPositionSlider, &LevelSlider::valueChanged,
-             [this]( int index, double value ) { updateTriggerOffset( index, value, false ); } );
+             [ this ]( int index, double value ) { updateTriggerPosition( index, value, false ); } );
 
     connect( mainSliders.triggerLevelSlider, &LevelSlider::valueChanged, this, &DsoWidget::updateTriggerLevel );
     connect( zoomSliders.triggerLevelSlider, &LevelSlider::valueChanged, this, &DsoWidget::updateTriggerLevel );
 
     // show a horizontal level line as long as the trigger level slider is active
-    connect( mainSliders.triggerLevelSlider, &LevelSlider::valueChanged, [this]( int index, double value, bool pressed ) {
+    connect( mainSliders.triggerLevelSlider, &LevelSlider::valueChanged, [ this ]( int index, double value, bool pressed ) {
         mainScope->generateGrid( index, value, pressed );
         zoomScope->generateGrid( index, value, pressed );
     } );
-    connect( zoomSliders.triggerLevelSlider, &LevelSlider::valueChanged, [this]( int index, double value, bool pressed ) {
+    connect( zoomSliders.triggerLevelSlider, &LevelSlider::valueChanged, [ this ]( int index, double value, bool pressed ) {
         mainScope->generateGrid( index, value, pressed );
         zoomScope->generateGrid( index, value, pressed );
     } );
 
-    connect( mainSliders.markerSlider, &LevelSlider::valueChanged, [this]( int index, double value ) {
+    connect( mainSliders.markerSlider, &LevelSlider::valueChanged, [ this ]( int index, double value ) {
         updateMarker( unsigned( index ), value );
         mainScope->updateCursor();
         zoomScope->updateCursor();
@@ -308,6 +319,12 @@ DsoWidget::DsoWidget( DsoSettingsScope *scope, DsoSettingsView *view, const Dso:
 }
 
 
+DsoWidget::~DsoWidget() {
+    if ( scope->verboseLevel > 1 )
+        qDebug() << " DsoWidget::~DsoWidget()";
+}
+
+
 void DsoWidget::switchToPrintColors() {
     if ( view->printerColorImages ) {
         view->colors = &view->print;
@@ -325,9 +342,11 @@ void DsoWidget::restoreScreenColors() {
 
 
 void DsoWidget::setColors() {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  DsoWidget::setColors()";
     // Palette for this widget
     QPalette paletteNow;
-    paletteNow.setColor( QPalette::Background, view->colors->background );
+    paletteNow.setColor( QPalette::Window, view->colors->background );
     paletteNow.setColor( QPalette::WindowText, view->colors->text );
     settingsSamplesOnScreen->setPalette( paletteNow );
     settingsSamplerateLabel->setPalette( paletteNow );
@@ -340,6 +359,8 @@ void DsoWidget::setColors() {
     markerFrequencybaseLabel->setPalette( paletteNow );
     QPalette tablePalette = paletteNow;
     for ( ChannelID channel = 0; channel < scope->voltage.size(); ++channel ) {
+        tablePalette.setColor( QPalette::WindowText, view->colors->spectrum[ channel ] );
+        measurementMagnitudeLabel[ channel ]->setPalette( tablePalette );
         tablePalette.setColor( QPalette::WindowText, view->colors->voltage[ channel ] );
         measurementNameLabel[ channel ]->setPalette( tablePalette );
         measurementMiscLabel[ channel ]->setPalette( tablePalette );
@@ -348,16 +369,14 @@ void DsoWidget::setColors() {
         zoomSliders.voltageOffsetSlider->setColor( ( channel ), view->colors->voltage[ channel ] );
         mainSliders.voltageOffsetSlider->setColor( unsigned( scope->voltage.size() ) + channel, view->colors->spectrum[ channel ] );
         zoomSliders.voltageOffsetSlider->setColor( unsigned( scope->voltage.size() ) + channel, view->colors->spectrum[ channel ] );
-        tablePalette.setColor( QPalette::WindowText, view->colors->spectrum[ channel ] );
-        measurementMagnitudeLabel[ channel ]->setPalette( tablePalette );
-        measurementVppLabel[ channel ]->setPalette( paletteNow );
-        measurementDCLabel[ channel ]->setPalette( paletteNow );
-        measurementACLabel[ channel ]->setPalette( paletteNow );
-        measurementRMSLabel[ channel ]->setPalette( paletteNow );
-        measurementdBLabel[ channel ]->setPalette( paletteNow );
-        measurementRMSPowerLabel[ channel ]->setPalette( paletteNow );
-        measurementTHDLabel[ channel ]->setPalette( paletteNow );
-        measurementFrequencyLabel[ channel ]->setPalette( paletteNow );
+        measurementVppLabel[ channel ]->setPalette( tablePalette );
+        measurementDCLabel[ channel ]->setPalette( tablePalette );
+        measurementACLabel[ channel ]->setPalette( tablePalette );
+        measurementRMSLabel[ channel ]->setPalette( tablePalette );
+        measurementdBLabel[ channel ]->setPalette( tablePalette );
+        measurementRMSPowerLabel[ channel ]->setPalette( tablePalette );
+        measurementTHDLabel[ channel ]->setPalette( tablePalette );
+        measurementFrequencyLabel[ channel ]->setPalette( tablePalette );
     }
 
     tablePalette = palette();
@@ -365,7 +384,7 @@ void DsoWidget::setColors() {
     settingsTriggerLabel->setPalette( tablePalette );
     updateTriggerSource();
     setPalette( paletteNow );
-    setBackgroundRole( QPalette::Background );
+    setBackgroundRole( QPalette::Window );
 }
 
 
@@ -401,6 +420,8 @@ void DsoWidget::updateCursorGrid( bool enabled ) {
 
 
 void DsoWidget::setupSliders( DsoWidget::Sliders &sliders ) {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  DsoWidget::setupSliders()";
     // The offset sliders for all possible channels
     sliders.voltageOffsetSlider = new LevelSlider( Qt::RightArrow );
     for ( ChannelID channel = 0; channel < scope->voltage.size(); ++channel ) {
@@ -426,7 +447,7 @@ void DsoWidget::setupSliders( DsoWidget::Sliders &sliders ) {
     sliders.triggerPositionSlider->addSlider();
     sliders.triggerPositionSlider->setLimits( 0, 0.0, 1.0 );
     sliders.triggerPositionSlider->setStep( 0, 0.2 / double( DIVS_TIME ) );
-    sliders.triggerPositionSlider->setValue( 0, scope->trigger.offset );
+    sliders.triggerPositionSlider->setValue( 0, scope->trigger.position );
     sliders.triggerPositionSlider->setIndexVisible( 0, true );
 
     // The sliders for the trigger levels
@@ -507,14 +528,16 @@ void DsoWidget::setMeasurementVisible( ChannelID channel ) {
 
 /// \brief Update the label about the marker measurements
 void DsoWidget::updateMarkerDetails() {
+    if ( scope->verboseLevel > 4 )
+        qDebug() << "    DsoWidget::updateMarkerDetails()";
     double m1 = scope->horizontal.cursor.pos[ 0 ].x() + DIVS_TIME / 2; // zero at center -> zero at left margin
     double m2 = scope->horizontal.cursor.pos[ 1 ].x() + DIVS_TIME / 2; // zero at center -> zero at left margin
     if ( m1 > m2 )
         std::swap( m1, m2 );
     double divs = m2 - m1;
     // t = 0 at trigger position
-    double time0 = ( m1 - DIVS_TIME * scope->trigger.offset ) * scope->horizontal.timebase;
-    double time1 = ( m2 - DIVS_TIME * scope->trigger.offset ) * scope->horizontal.timebase;
+    double time0 = ( m1 - DIVS_TIME * scope->trigger.position ) * scope->horizontal.timebase;
+    double time1 = ( m2 - DIVS_TIME * scope->trigger.position ) * scope->horizontal.timebase;
     double time = divs * scope->horizontal.timebase;
     double freq0 = m1 * scope->horizontal.frequencybase;
     double freq1 = m2 * scope->horizontal.frequencybase;
@@ -522,9 +545,7 @@ void DsoWidget::updateMarkerDetails() {
     bool timeUsed = false;
     bool freqUsed = false;
 
-    int index = 0;
-    cursorDataGrid->updateInfo( unsigned( index++ ), true, QString(), valueToString( time, UNIT_SECONDS, 3 ),
-                                valueToString( freq, UNIT_HERTZ, 3 ) );
+    int index = 1;
 
     for ( ChannelID channel = 0; channel < scope->voltage.size(); ++channel ) {
         if ( scope->voltage[ channel ].used ) {
@@ -605,6 +626,16 @@ void DsoWidget::updateMarkerDetails() {
         } else
             markerFrequencyLabel->setText( "" );
     }
+
+    QString markerMeasureTimeLabel;
+    QString markerMeasureFreqLabel;
+    if ( timeUsed ) {
+        markerMeasureTimeLabel = QString( "Δt: %1" ).arg( valueToString( time, UNIT_SECONDS, 3 ) );
+    }
+    if ( freqUsed ) {
+        markerMeasureFreqLabel = QString( "Δf: %1" ).arg( valueToString( freq, UNIT_HERTZ, 3 ) );
+    }
+    cursorDataGrid->updateInfo( unsigned( 0 ), true, QString(), markerMeasureTimeLabel, markerMeasureFreqLabel );
 }
 
 
@@ -626,7 +657,7 @@ void DsoWidget::updateTriggerDetails() {
     tablePalette.setColor( QPalette::WindowText, view->colors->voltage[ unsigned( scope->trigger.source ) ] );
     settingsTriggerLabel->setPalette( tablePalette );
     QString levelString = valueToString( scope->voltage[ unsigned( scope->trigger.source ) ].trigger, UNIT_VOLTS, 3 );
-    QString pretriggerString = tr( "%L1%" ).arg( int( round( scope->trigger.offset * 100 ) ) );
+    QString pretriggerString = tr( "%L1%" ).arg( int( round( scope->trigger.position * 100 ) ) );
     QString pre = Dso::slopeString( scope->trigger.slope ); // trigger slope
     QString post = pre;                                     // opposite trigger slope
     if ( scope->trigger.slope == Dso::Slope::Positive )
@@ -695,17 +726,22 @@ void DsoWidget::updateTimebase( double newTimebase ) {
 
 /// \brief Handles magnitudeChanged signal from the spectrum dock.
 /// \param channel The channel whose magnitude was changed.
-void DsoWidget::updateSpectrumMagnitude( ChannelID channel ) { updateSpectrumDetails( channel ); }
+void DsoWidget::updateSpectrumMagnitude( ChannelID channel ) {
+    updateSpectrumDetails( channel );
+    updateMarkerDetails();
+}
 
 /// \brief Handles usedChanged signal from the spectrum dock.
 /// \param channel The channel whose used-state was changed.
 /// \param used The new used-state for the channel.
 void DsoWidget::updateSpectrumUsed( ChannelID channel, bool used ) {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  DsoWidget::updateSpectrumUsed()" << channel << used;
     if ( channel >= unsigned( scope->voltage.size() ) )
         return;
     bool spectrumUsed = false;
-    for ( size_t channel = 0; channel < scope->voltage.size(); ++channel )
-        if ( scope->spectrum[ channel ].used )
+    for ( size_t ch = 0; ch < scope->voltage.size(); ++ch )
+        if ( scope->spectrum[ ch ].used )
             spectrumUsed = true;
     settingsFrequencybaseLabel->setVisible( spectrumUsed ); // hide text if no spectrum channel used
     mainSliders.voltageOffsetSlider->setIndexVisible( unsigned( scope->voltage.size() ) + channel, used );
@@ -766,6 +802,8 @@ void DsoWidget::updateVoltageGain( ChannelID channel ) {
         adaptTriggerLevelSlider( zoomSliders, channel );
     }
     updateVoltageDetails( channel );
+
+    updateMarkerDetails();
 }
 
 
@@ -773,11 +811,11 @@ void DsoWidget::updateVoltageGain( ChannelID channel ) {
 /// \param channel The channel whose used-state was changed.
 /// \param used The new used-state for the channel.
 void DsoWidget::updateVoltageUsed( ChannelID channel, bool used ) {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  DsoWidget::updateVoltageUsed()" << channel << used;
     if ( channel >= unsigned( scope->voltage.size() ) )
         return;
 
-    //    if (!used && cursorDataGrid->voltageCursors[channel].selector->isChecked()) cursorDataGrid->selectItem(0);
-
     mainSliders.voltageOffsetSlider->setIndexVisible( channel, used );
     zoomSliders.voltageOffsetSlider->setIndexVisible( channel, used );
 
@@ -798,6 +836,8 @@ void DsoWidget::updateRecordLength( unsigned long size ) {
 
 /// \brief Show/hide the zoom view.
 void DsoWidget::updateZoom( bool enabled ) {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  DsoWidget::updateZoom()" << enabled;
     mainLayout->setRowStretch( zoomScopeRow, enabled ? 1 : 0 );
     zoomScope->setVisible( enabled );
     zoomSliders.voltageOffsetSlider->setVisible( enabled );
@@ -816,16 +856,18 @@ void DsoWidget::updateZoom( bool enabled ) {
 
 /// \brief Prints analyzed data.
 void DsoWidget::showNew( std::shared_ptr< PPresult > analysedData ) {
+    if ( scope->verboseLevel > 4 )
+        qDebug() << "    DsoWidget::showNew()" << analysedData->tag;
     mainScope->showData( analysedData );
     zoomScope->showData( analysedData );
 
     QPalette triggerLabelPalette = palette();
     if ( scope->trigger.mode == Dso::TriggerMode::ROLL ) {
         triggerLabelPalette.setColor( QPalette::WindowText, view->colors->background );
-        triggerLabelPalette.setColor( QPalette::Background, view->colors->background );
+        triggerLabelPalette.setColor( QPalette::Window, view->colors->background );
     } else {
         triggerLabelPalette.setColor( QPalette::WindowText, Qt::black );
-        triggerLabelPalette.setColor( QPalette::Background, analysedData->softwareTriggerTriggered ? Qt::green : Qt::red );
+        triggerLabelPalette.setColor( QPalette::Window, analysedData->softwareTriggerTriggered ? Qt::green : Qt::red );
     }
     swTriggerStatus->setPalette( triggerLabelPalette );
     swTriggerStatus->setVisible( true );
@@ -851,24 +893,24 @@ void DsoWidget::showNew( std::shared_ptr< PPresult > analysedData ) {
             measurementFrequencyLabel[ channel ]->setText(
                 valueToString( analysedData.get()->data( channel )->frequency, UNIT_HERTZ, 4 ) );
             // RMS Amplitude string representation (3 significant digits)
-            if ( scope->analysis.dummyLoad ) {
-                measurementLayout->setColumnStretch( 9, 3 ); // Power
+            if ( scope->analysis.dummyLoad ) { // != 0 -> show
+                measurementLayout->setColumnStretch( 9, 3 );
                 measurementRMSPowerLabel[ channel ]->setText(
                     valueToString( ( analysedData.get()->data( channel )->rms * analysedData.get()->data( channel )->rms ) /
                                        scope->analysis.dummyLoad,
                                    UNIT_WATTS, 3 ) );
-            } else {
-                measurementLayout->setColumnStretch( 9, 0 ); // Power
+            } else { // do not show this label
                 measurementRMSPowerLabel[ channel ]->setText( "" );
+                measurementLayout->setColumnStretch( 9, 0 ); // Power
             }
             if ( scope->analysis.calculateTHD ) {
-                measurementLayout->setColumnStretch( 10, 2 ); // THD
-                if ( analysedData.get()->data( channel )->thd > 0 )
-                    measurementTHDLabel[ channel ]->setText(
-                        QString( "%1%" ).arg( analysedData.get()->data( channel )->thd * 100, 4, 'f', 1 ) );
-                else
+                double thd = analysedData.get()->data( channel )->thd;
+                measurementLayout->setColumnStretch( 10, 2 );
+                if ( thd > 0 ) // display either xx.x% or xxx%
+                    measurementTHDLabel[ channel ]->setText( QString( "%L1%" ).arg( thd * 100, 4, 'f', thd < 1 ? 1 : 0 ) );
+                else // invalid, blank label
                     measurementTHDLabel[ channel ]->setText( "" );
-            } else {
+            } else { // do not show this label
                 measurementTHDLabel[ channel ]->setText( "" );
                 measurementLayout->setColumnStretch( 10, 0 ); // THD
             }
@@ -877,10 +919,10 @@ void DsoWidget::showNew( std::shared_ptr< PPresult > analysedData ) {
             QPalette validPalette;
             if ( analysedData.get()->data( channel )->valid ) { // normal display
                 validPalette.setColor( QPalette::WindowText, view->colors->voltage[ channel ] );
-                validPalette.setColor( QPalette::Background, view->colors->background );
+                validPalette.setColor( QPalette::Window, view->colors->background );
             } else { // warning
                 validPalette.setColor( QPalette::WindowText, Qt::black );
-                validPalette.setColor( QPalette::Background, Qt::red );
+                validPalette.setColor( QPalette::Window, Qt::red );
             }
             measurementNameLabel[ channel ]->setPalette( validPalette );
         }
@@ -899,7 +941,7 @@ void DsoWidget::showEvent( QShowEvent *event ) {
     updateZoom( view->zoom );
 
     updateTriggerSource();
-    adaptTriggerOffsetSlider();
+    adaptTriggerPositionSlider();
 }
 
 
@@ -933,6 +975,8 @@ void DsoWidget::updateOffset( ChannelID channel, double value ) {
 #ifdef __GNUC__
 #pragma GCC diagnostic pop
 #endif
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  DsoWidget::updateOffset()" << channel << value;
     emit voltageOffsetChanged( channel, value );
 }
 
@@ -958,8 +1002,8 @@ double DsoWidget::zoomToMain( double position ) const {
 
 
 /// \brief Handles signals affecting trigger position in the zoom view.
-void DsoWidget::adaptTriggerOffsetSlider() {
-    double value = mainToZoom( scope->trigger.offset );
+void DsoWidget::adaptTriggerPositionSlider() {
+    double value = mainToZoom( scope->trigger.position );
 
     LevelSlider &slider = *zoomSliders.triggerPositionSlider;
     const QSignalBlocker blocker( slider );
@@ -981,23 +1025,24 @@ void DsoWidget::adaptTriggerOffsetSlider() {
 /// \param index The index of the slider.
 /// \param value The new triggerPosition in seconds relative to the first
 /// sample.
-void DsoWidget::updateTriggerOffset( int index, double value, bool mainView ) {
+void DsoWidget::updateTriggerPosition( int index, double value, bool mainView ) {
     if ( index != 0 )
         return;
 
     if ( mainView ) {
-        scope->trigger.offset = value;
-        adaptTriggerOffsetSlider();
+        scope->trigger.position = value;
+        adaptTriggerPositionSlider();
     } else {
-        scope->trigger.offset = zoomToMain( value );
+        scope->trigger.position = zoomToMain( value );
         const QSignalBlocker blocker( mainSliders.triggerPositionSlider );
-        mainSliders.triggerPositionSlider->setValue( index, scope->trigger.offset );
+        mainSliders.triggerPositionSlider->setValue( index, scope->trigger.position );
     }
 
     updateTriggerDetails();
     updateMarkerDetails();
-
-    emit triggerPositionChanged( scope->trigger.offset );
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  DsoWidget::updateTriggerPosition()" << scope->trigger.position;
+    emit triggerPositionChanged( scope->trigger.position );
 }
 
 
@@ -1023,7 +1068,8 @@ void DsoWidget::updateTriggerLevel( ChannelID channel, double value ) {
 #pragma GCC diagnostic pop
 #endif
     updateTriggerDetails();
-
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  DsoWidget::updateTriggerValue()" << channel << value;
     emit triggerLevelChanged( channel, value );
 }
 
@@ -1033,13 +1079,15 @@ void DsoWidget::updateTriggerLevel( ChannelID channel, double value ) {
 /// \param value The new marker position.
 void DsoWidget::updateMarker( unsigned marker, double value ) {
     scope->setMarker( marker, value );
-    adaptTriggerOffsetSlider();
+    adaptTriggerPositionSlider();
     updateMarkerDetails();
 }
 
 
 /// \brief Update the sliders settings.
 void DsoWidget::updateSlidersSettings() {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  DsoWidget::updateSlidersSettings()";
     // The offset sliders for all possible channels
     for ( ChannelID channel = 0; channel < scope->voltage.size(); ++channel ) {
         updateOffset( channel, scope->voltage[ channel ].offset );
@@ -1062,9 +1110,9 @@ void DsoWidget::updateSlidersSettings() {
     }
 
     // The trigger position slider
-    mainSliders.triggerPositionSlider->setValue( 0, scope->trigger.offset );
-    updateTriggerOffset( 0, scope->trigger.offset, true );                // main slider
-    updateTriggerOffset( 0, mainToZoom( scope->trigger.offset ), false ); // zoom slider
+    mainSliders.triggerPositionSlider->setValue( 0, scope->trigger.position );
+    updateTriggerPosition( 0, scope->trigger.position, true );                // main slider
+    updateTriggerPosition( 0, mainToZoom( scope->trigger.position ), false ); // zoom slider
 
     // The sliders for the trigger levels
     for ( ChannelID channel = 0; channel < spec->channels; ++channel ) {
