@@ -24,35 +24,39 @@
 #include "viewsettings.h"
 
 
-GlScope *GlScope::createNormal( DsoSettingsScope *scope, DsoSettingsView *view, QWidget *parent ) {
-    GlScope *s = new GlScope( scope, view, parent );
-    s->zoomed = false;
-    return s;
+// static info strings
+QString GlScope::OpenGLversion;
+QString GlScope::GLSLversion;
+
+
+QString GlScope::getOpenGLversion() {
+    if ( OpenGLversion.isNull() ) {
+        QOffscreenSurface surface;
+        surface.create();
+        QOpenGLContext context;
+        context.create();
+        context.makeCurrent( &surface );
+        OpenGLversion = reinterpret_cast< const char * >( context.functions()->glGetString( GL_VERSION ) );
+        qDebug() << OpenGLversion;
+        surface.destroy();
+    }
+    return OpenGLversion;
 }
 
 
-GlScope *GlScope::createZoomed( DsoSettingsScope *scope, DsoSettingsView *view, QWidget *parent ) {
-    GlScope *s = new GlScope( scope, view, parent );
-    s->zoomed = true;
-    return s;
-}
-
-
-void GlScope::useQSurfaceFormat( QSurfaceFormat::RenderableType t ) {
-    QCoreApplication::setAttribute( Qt::AA_ShareOpenGLContexts, true );
-
-    // Prefer full desktop OpenGL without fixed pipeline
+// this static function will be called early from main to set up OpenGL
+void GlScope::useOpenGLSLversion( QString renderer ) {
+    // QCoreApplication::setAttribute( Qt::AA_ShareOpenGLContexts, true ); // commented out because too late
     QSurfaceFormat format;
-    // TODO: check from time to time if warning has gone, comment next line for now
-    format.setSamples( 4 ); // antialiasing gives warning with some HW, Qt & OpenGL versions.
+    GLSLversion = renderer;
+    format.setSamples( 4 ); // ignore antialiasing warning with some HW, Qt & OpenGL versions.
     format.setProfile( QSurfaceFormat::CoreProfile );
-    if ( t == QSurfaceFormat::OpenGLES ) {
-        format.setVersion( 2, 0 );
+    if ( renderer == GLES100 ) {
         format.setRenderableType( QSurfaceFormat::OpenGLES );
-        QCoreApplication::setAttribute( Qt::AA_UseOpenGLES, true );
+        // QCoreApplication::setAttribute( Qt::AA_UseOpenGLES, true ); // commented out because too late
     } else {
-        format.setVersion( 3, 2 );
         format.setRenderableType( QSurfaceFormat::OpenGL );
+        // QCoreApplication::setAttribute( Qt::AA_UseOpenGLES, false ); // commented out because too late
     }
     QSurfaceFormat::setDefaultFormat( format );
 }
@@ -60,20 +64,8 @@ void GlScope::useQSurfaceFormat( QSurfaceFormat::RenderableType t ) {
 
 GlScope::GlScope( DsoSettingsScope *scope, DsoSettingsView *view, QWidget *parent )
     : QOpenGLWidget( parent ), scope( scope ), view( view ) {
-    // get OpenGL version to define appropriate OpenGLSL version
-    // reason:
-    // some not so new intel graphic driver report a very conservative version
-    // e.g. debian buster -> "2.1 Mesa 18.3.4"
-    QOffscreenSurface surface;
-    surface.create();
-    QOpenGLContext context;
-    context.create();
-    context.makeCurrent( &surface );
-    QString glVersion = reinterpret_cast< const char * >( context.functions()->glGetString( GL_VERSION ) );
-    GLSLversion = glVersion >= "3.2" ? 150 : 120; // version string "3.2 xxxx" > "3.2" is true
-    // qDebug() << "OpenGL version" << glVersion << GLSLversion;
-    surface.destroy();
-
+    if ( scope->verboseLevel > 1 )
+        qDebug() << " GLScope::GLScope()";
     cursorInfo.clear();
     cursorInfo.push_back( &scope->horizontal.cursor );
     selectedCursor = 0;
@@ -88,6 +80,24 @@ GlScope::GlScope( DsoSettingsScope *scope, DsoSettingsView *view, QWidget *paren
 
 
 GlScope::~GlScope() { /* virtual destructor necessary */
+    if ( scope->verboseLevel > 1 )
+        qDebug() << " GLScope::~GLScope()";
+}
+
+
+// static
+GlScope *GlScope::createNormal( DsoSettingsScope *scope, DsoSettingsView *view, QWidget *parent ) {
+    GlScope *s = new GlScope( scope, view, parent );
+    s->zoomed = false;
+    return s;
+}
+
+
+// static
+GlScope *GlScope::createZoomed( DsoSettingsScope *scope, DsoSettingsView *view, QWidget *parent ) {
+    GlScope *s = new GlScope( scope, view, parent );
+    s->zoomed = true;
+    return s;
 }
 
 
@@ -106,6 +116,8 @@ QPointF GlScope::posToPosition( QPointF pos ) {
 
 
 void GlScope::mousePressEvent( QMouseEvent *event ) {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  GLS::mPE()" << event;
     if ( !( zoomed && selectedCursor == 0 ) && event->button() == Qt::LeftButton ) {
         QPointF position = posToPosition( event->pos() );
         selectedMarker = NO_MARKER;
@@ -158,6 +170,8 @@ void GlScope::mousePressEvent( QMouseEvent *event ) {
 
 
 void GlScope::mouseMoveEvent( QMouseEvent *event ) {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  GLS::mME()" << event;
     if ( !( zoomed && selectedCursor == 0 ) && ( event->buttons() & Qt::LeftButton ) != 0 ) {
         QPointF position = posToPosition( event->pos() );
         if ( selectedMarker == NO_MARKER ) {
@@ -179,6 +193,8 @@ void GlScope::mouseMoveEvent( QMouseEvent *event ) {
 
 
 void GlScope::mouseReleaseEvent( QMouseEvent *event ) {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  GLS::mRE()" << event;
     if ( !( zoomed && selectedCursor == 0 ) && event->button() == Qt::LeftButton ) {
         QPointF position = posToPosition( event->pos() );
         if ( selectedMarker < 2 ) {
@@ -193,6 +209,8 @@ void GlScope::mouseReleaseEvent( QMouseEvent *event ) {
 
 
 void GlScope::mouseDoubleClickEvent( QMouseEvent *event ) {
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  GLS::mDCE()" << event;
     if ( !( zoomed && selectedCursor == 0 ) && ( event->buttons() & Qt::LeftButton ) != 0 ) {
         // left double click positions two markers left and right of clicked pos with zoom=100
         QPointF position = posToPosition( event->pos() );
@@ -202,7 +220,7 @@ void GlScope::mouseDoubleClickEvent( QMouseEvent *event ) {
             if ( event->modifiers() & Qt::CTRL ) // 100x zoom
                 p /= 10;
             if ( event->modifiers() & Qt::SHIFT ) // center at trigger position
-                position = QPointF( 10 * scope->trigger.offset - 5, 0 );
+                position = QPointF( 10 * scope->trigger.position - 5, 0 );
             // move 1st marker left of current position.
             cursorInfo[ selectedCursor ]->pos[ 0 ] = position - p;
             emit markerMoved( selectedCursor, 0 );
@@ -224,7 +242,9 @@ void GlScope::mouseDoubleClickEvent( QMouseEvent *event ) {
 
 
 void GlScope::wheelEvent( QWheelEvent *event ) {
-    static std::vector< int > zoomList = {1, 2, 5, 10, 20, 50, 100, 200, 500};
+    if ( scope->verboseLevel > 2 )
+        qDebug() << "  GLS::wE()" << event;
+    static std::vector< int > zoomList = { 1, 2, 5, 10, 20, 50, 100, 200, 500 };
     if ( !( zoomed && selectedCursor == 0 ) ) {
         if ( selectedMarker == NO_MARKER ) {
             double step = event->angleDelta().y() / 1200.0; // one click = 0.1
@@ -269,14 +289,15 @@ void GlScope::paintEvent( QPaintEvent *event ) {
         font.setPointSize( 18 );
         painter.setFont( font );
         painter.drawText( rect(), Qt::AlignCenter | Qt::TextWordWrap, errorMessage );
+        fprintf( stderr, "%s", errorMessage.toUtf8().data() );
     }
     event->accept(); // consume the event
 }
 
 
-unsigned GlScope::forceGLSLversion = 0;
-
 void GlScope::initializeGL() {
+    if ( scope->verboseLevel )
+        qDebug() << "GLScope::initializeGL()";
     if ( !QOpenGLShaderProgram::hasOpenGLShaderPrograms( context() ) ) {
         errorMessage = tr( "System does not support OpenGL Shading Language (GLSL)" );
         return;
@@ -288,7 +309,7 @@ void GlScope::initializeGL() {
 
     auto program = std::unique_ptr< QOpenGLShaderProgram >( new QOpenGLShaderProgram( context() ) );
 
-    const char *vshaderES = R"(
+    const char *vertexShaderGL100ES = R"(
           #version 100
           attribute highp vec3 vertex;
           uniform mat4 matrix;
@@ -298,13 +319,8 @@ void GlScope::initializeGL() {
               gl_PointSize = 1.0;
           }
     )";
-    const char *fshaderES = R"(
-          #version 100
-          uniform highp vec4 colour;
-          void main() { gl_FragColor = colour; }
-    )";
 
-    const char *vshaderDesktop120 = R"(
+    const char *vertexShaderGLSL120 = R"(
           #version 120
           attribute highp vec3 vertex;
           uniform mat4 matrix;
@@ -314,13 +330,8 @@ void GlScope::initializeGL() {
               gl_PointSize = 1.0;
           }
     )";
-    const char *fshaderDesktop120 = R"(
-          #version 120
-          uniform highp vec4 colour;
-          void main() { gl_FragColor = colour; }
-    )";
 
-    const char *vshaderDesktop150 = R"(
+    const char *vertexShaderGLSL150 = R"(
           #version 150
           in highp vec3 vertex;
           uniform mat4 matrix;
@@ -330,37 +341,66 @@ void GlScope::initializeGL() {
               gl_PointSize = 1.0;
           }
     )";
-    const char *fshaderDesktop150 = R"(
-          #version 150
-          uniform highp vec4 colour;
-          out vec4 flatColor;
-          void main() { flatColor = colour; }
+
+    const char *fragmentShaderGL100ES = R"(
+          #version 100
+          uniform highp vec4 color;
+          void main() { gl_FragColor = color; }
     )";
 
-    if ( GlScope::forceGLSLversion )
-        GLSLversion = GlScope::forceGLSLversion;
-    // qDebug() << "compile shaders" << GlScope::forceGLSLversion << GLSLversion;
+    const char *fragmentShaderGLSL120 = R"(
+          #version 120
+          uniform highp vec4 color;
+          void main() { gl_FragColor = color; }
+    )";
 
-    const char *vshaderDesktop = GLSLversion == 120 ? vshaderDesktop120 : vshaderDesktop150;
-    const char *fshaderDesktop = GLSLversion == 120 ? fshaderDesktop120 : fshaderDesktop150;
+    const char *fragmentShaderGLSL150 = R"(
+          #version 150
+          uniform highp vec4 color;
+          out vec4 flatColor;
+          void main() { flatColor = color; }
+    )";
 
-    // Compile vertex shader
-    bool usesOpenGL = QSurfaceFormat::defaultFormat().renderableType() == QSurfaceFormat::OpenGL;
-    if ( !program->addShaderFromSourceCode( QOpenGLShader::Vertex, usesOpenGL ? vshaderDesktop : vshaderES ) ||
-         !program->addShaderFromSourceCode( QOpenGLShader::Fragment, usesOpenGL ? fshaderDesktop : fshaderES ) ) {
-        errorMessage = tr( "Failed to compile OpenGL shader programs.\n" ) + program->log();
-        return;
+    // Compile vertex and fragment shader
+    QString GLEShint;
+    if ( GLES100 != GLSLversion )                                 // regular OpenGL
+        GLEShint = tr( "Try command line option '--useGLES'\n" ); // offer OpenGL ES as fall back solution
+    QString OpenGLinfo = "Graphic: " + OpenGLversion;
+    renderInfo = OpenGLinfo + " - GLSL version " + GLSLversion;
+    qDebug() << renderInfo.toLocal8Bit().data();
+    if ( GLSL150 == GLSLversion ) { // use version 150 if supported by OpenGL version >= 3.2
+        if ( !program->addShaderFromSourceCode( QOpenGLShader::Vertex, vertexShaderGLSL150 ) ||
+             !program->addShaderFromSourceCode( QOpenGLShader::Fragment, fragmentShaderGLSL150 ) ) {
+            qWarning() << "Switching to GLSL version 1.20, use the command line option '--useGLSL120' or '--useGLES'";
+            GLSLversion = GLSL120; // in case of error try version 120 as fall back
+        }
+    }
+    if ( GLSL120 == GLSLversion ) { // this version is supported by OpenGL version >= 2.1 (older HW/SW)
+        if ( !program->addShaderFromSourceCode( QOpenGLShader::Vertex, vertexShaderGLSL120 ) ||
+             !program->addShaderFromSourceCode( QOpenGLShader::Fragment, fragmentShaderGLSL120 ) ) {
+            errorMessage =
+                tr( "Failed to compile OpenGL shader programs.\n" ) + GLEShint + OpenGLinfo + QString( "\n" ) + program->log();
+            return; // in case of error propose the use of OpenGLES (OpenGL for embedded systems) and stop
+        }
+    }
+    if ( GLES100 == GLSLversion ) { // use OpenGLES
+        if ( !program->addShaderFromSourceCode( QOpenGLShader::Vertex, vertexShaderGL100ES ) ||
+             !program->addShaderFromSourceCode( QOpenGLShader::Fragment, fragmentShaderGL100ES ) ) {
+            errorMessage = tr( "Failed to compile OpenGL shader programs.\n" ) + OpenGLinfo + QString( "\n" ) + program->log();
+            return;
+        }
     }
 
     // Link shader pipeline
     if ( !program->link() || !program->bind() ) {
-        errorMessage = tr( "Failed to link/bind OpenGL shader programs.\n" ) + program->log();
+        errorMessage =
+            tr( "Failed to link/bind OpenGL shader programs.\n" ) + GLEShint + renderInfo + QString( "\n" ) + program->log();
         return;
     }
 
     vertexLocation = program->attributeLocation( "vertex" );
     matrixLocation = program->uniformLocation( "matrix" );
-    colorLocation = program->uniformLocation( "colour" );
+    colorLocation = program->uniformLocation( "color" );
 
     if ( vertexLocation == -1 || colorLocation == -1 || matrixLocation == -1 ) {
         qWarning() << tr( "Failed to locate shader variable." );
@@ -382,17 +422,15 @@ void GlScope::initializeGL() {
     QColor bg = view->colors->background;
     gl->glClearColor( GLfloat( bg.redF() ), GLfloat( bg.greenF() ), GLfloat( bg.blueF() ), GLfloat( bg.alphaF() ) );
 
+    m_vaoMarker.create();
+    QOpenGLVertexArrayObject::Binder b( &m_vaoMarker );
+    m_marker.create();
+    m_marker.bind();
+    m_marker.setUsagePattern( QOpenGLBuffer::StaticDraw );
+    m_marker.allocate( int( vaMarker.size() * sizeof( Vertices ) ) );
+    program->enableAttributeArray( vertexLocation );
+    program->setAttributeBuffer( vertexLocation, GL_FLOAT, 0, 3, 0 );
 
-    {
-        m_vaoMarker.create();
-        QOpenGLVertexArrayObject::Binder b( &m_vaoMarker );
-        m_marker.create();
-        m_marker.bind();
-        m_marker.setUsagePattern( QOpenGLBuffer::StaticDraw );
-        m_marker.allocate( int( vaMarker.size() * sizeof( Vertices ) ) );
-        program->enableAttributeArray( vertexLocation );
-        program->setAttributeBuffer( vertexLocation, GL_FLOAT, 0, 3, 0 );
-    }
     updateCursor();
 
     m_program = std::move( program );
@@ -431,32 +469,32 @@ void GlScope::generateVertices( unsigned marker, const DsoSettingsScopeCursor &c
     const float Z_ORDER = 1.0f;
     switch ( cursor.shape ) {
     case DsoSettingsScopeCursor::NONE:
-        vaMarker[ marker ] = {QVector3D( -DIVS_TIME, -DIVS_VOLTAGE, Z_ORDER ), QVector3D( -DIVS_TIME, DIVS_VOLTAGE, Z_ORDER ),
-                              QVector3D( DIVS_TIME, DIVS_VOLTAGE, Z_ORDER ), QVector3D( DIVS_TIME, -DIVS_VOLTAGE, Z_ORDER )};
+        vaMarker[ marker ] = { QVector3D( -DIVS_TIME, -DIVS_VOLTAGE, Z_ORDER ), QVector3D( -DIVS_TIME, DIVS_VOLTAGE, Z_ORDER ),
+                               QVector3D( DIVS_TIME, DIVS_VOLTAGE, Z_ORDER ), QVector3D( DIVS_TIME, -DIVS_VOLTAGE, Z_ORDER ) };
         break;
     case DsoSettingsScopeCursor::VERTICAL:
-        vaMarker[ marker ] = {QVector3D( GLfloat( cursor.pos[ 0 ].x() ), -GLfloat( DIVS_VOLTAGE ), Z_ORDER ),
-                              QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( DIVS_VOLTAGE ), Z_ORDER ),
-                              QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( DIVS_VOLTAGE ), Z_ORDER ),
-                              QVector3D( GLfloat( cursor.pos[ 1 ].x() ), -GLfloat( DIVS_VOLTAGE ), Z_ORDER )};
+        vaMarker[ marker ] = { QVector3D( GLfloat( cursor.pos[ 0 ].x() ), -GLfloat( DIVS_VOLTAGE ), Z_ORDER ),
+                               QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( DIVS_VOLTAGE ), Z_ORDER ),
+                               QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( DIVS_VOLTAGE ), Z_ORDER ),
+                               QVector3D( GLfloat( cursor.pos[ 1 ].x() ), -GLfloat( DIVS_VOLTAGE ), Z_ORDER ) };
         break;
     case DsoSettingsScopeCursor::HORIZONTAL:
-        vaMarker[ marker ] = {QVector3D( -GLfloat( DIVS_TIME ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
-                              QVector3D( GLfloat( DIVS_TIME ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
-                              QVector3D( GLfloat( DIVS_TIME ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ),
-                              QVector3D( -GLfloat( DIVS_TIME ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER )};
+        vaMarker[ marker ] = { QVector3D( -GLfloat( DIVS_TIME ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
+                               QVector3D( GLfloat( DIVS_TIME ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
+                               QVector3D( GLfloat( DIVS_TIME ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ),
+                               QVector3D( -GLfloat( DIVS_TIME ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ) };
         break;
     case DsoSettingsScopeCursor::RECTANGULAR:
         if ( ( cursor.pos[ 1 ].x() - cursor.pos[ 0 ].x() ) * ( cursor.pos[ 1 ].y() - cursor.pos[ 0 ].y() ) > 0.0 ) {
-            vaMarker[ marker ] = {QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
-                                  QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
-                                  QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ),
-                                  QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER )};
+            vaMarker[ marker ] = { QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
+                                   QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
+                                   QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ),
+                                   QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ) };
         } else {
-            vaMarker[ marker ] = {QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
-                                  QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ),
-                                  QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ),
-                                  QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER )};
+            vaMarker[ marker ] = { QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ),
+                                   QVector3D( GLfloat( cursor.pos[ 0 ].x() ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ),
+                                   QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( cursor.pos[ 1 ].y() ), Z_ORDER ),
+                                   QVector3D( GLfloat( cursor.pos[ 1 ].x() ), GLfloat( cursor.pos[ 0 ].y() ), Z_ORDER ) };
         }
         break;
     }
@@ -552,8 +590,8 @@ void GlScope::resizeGL( int width, int height ) {
 // section 0:grid, 1:axes, 2:border
 void GlScope::draw4Cross( std::vector< QVector3D > &va, int section, float x, float y ) {
     const float d = 0.05f; // cross size
-    for ( int xSign : {-1, 1} ) {
-        for ( int ySign : {-1, 1} ) {
+    for ( int xSign : { -1, 1 } ) {
+        for ( int ySign : { -1, 1 } ) {
             gridDrawCounts[ section ] += 4;
             va.push_back( QVector3D( xSign * ( x - d ), ySign * y, 0 ) );
             va.push_back( QVector3D( xSign * ( x + d ), ySign * y, 0 ) );
@@ -563,6 +601,7 @@ void GlScope::draw4Cross( std::vector< QVector3D > &va, int section, float x, fl
     }
 }
 
+
 // prepare the static grid structure that is shown by 'drawGrid()'
 // show a line as long as the trigger level marker is clicked or moved
 // index: channel, value: trigger level, pressed: marker is activated
@@ -691,7 +730,6 @@ void GlScope::generateGrid( int index, double value, bool pressed ) {
 
     ++item;
 
-
     { // prepare (dynamic) trigger level marker line
         if ( !m_vaoGrid[ item ].isCreated() )
             m_vaoGrid[ item ].create();
@@ -734,7 +772,6 @@ void GlScope::drawGrid() {
     gl->glDrawArrays( GL_POINTS, 0, gridDrawCounts[ item ] );
     m_vaoGrid[ item ].release();
 
-
     // Axes and div crosses
     ++item;
     m_vaoGrid[ item ].bind();
@@ -804,7 +841,7 @@ void GlScope::drawVoltageChannelGraph( ChannelID channel, Graph &graph, int hist
 
 
 void GlScope::drawHistogramChannelGraph( ChannelID channel, Graph &graph, int historyIndex ) {
-    if ( !scope->voltage[ channel ].used )
+    if ( graph.vaoHistogram.empty() || !scope->voltage[ channel ].used )
         return;
 
     m_program->setUniformValue( colorLocation, view->colors->voltage[ channel ].darker( 100 + 10 * historyIndex ) );
