@@ -34,6 +34,10 @@
 
 MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, ExporterRegistry *exporterRegistry, QWidget *parent )
     : QMainWindow( parent ), ui( new Ui::MainWindow ), dsoSettings( settings ), exporterRegistry( exporterRegistry ) {
+
+    if ( dsoSettings->scope.verboseLevel > 1 )
+        qDebug() << " MainWindow::MainWindow()";
+
     // suppress nasty warnings, e.g. "kf5.kio.core: Invalid URL ..." or "qt.qpa.xcb: QXcbConnection: XCB error: 3 (BadWindow) ..."
     QLoggingCategory::setFilterRules( "kf5.kio.core=false\nqt.qpa.xcb=false" );
     QVariantMap colorMap;
@@ -81,7 +85,7 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     setWindowIcon( QIcon( ":/images/OpenHantek.svg" ) );
     setWindowTitle( dsoControl->getDevice()->isRealHW()
                         ? tr( "OpenHantek6022 (%1) - Device %2 (FW%3)" )
-                              .arg( QString::fromStdString( VERSION ), QString::fromStdString( dsoControl->getModel()->name ) )
+                              .arg( QString::fromStdString( VERSION ), dsoControl->getModel()->name )
                               .arg( dsoControl->getDevice()->getFwVersion(), 4, 16, QChar( '0' ) )
                         : tr( "OpenHantek6022 (%1) - " ).arg( QString::fromStdString( VERSION ) ) + tr( "Demo Mode" ) );
 
@@ -89,24 +93,39 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     setDockOptions( dockOptions() | QMainWindow::GroupedDragging );
 #endif
     QAction *action;
-    action = new QAction( iconFont->icon( fa::camera, colorMap ), tr( "Screenshot .." ), this );
-    action->setToolTip( "Make a screenshot of the program window" );
-    connect( action, &QAction::triggered, [this]() { screenShot( SCREENSHOT ); } );
+    action = new QAction( iconFont->icon( fa::camera, colorMap ), tr( "Screenshot" ), this );
+    action->setToolTip( "Make an immediate screenshot of the program window" );
+    connect( action, &QAction::triggered, [ this ]() { screenShot( SCREENSHOT, true ); } );
     ui->menuExport->addAction( action );
 
-    action = new QAction( iconFont->icon( fa::camera, colorMap ), tr( "Hardcopy .." ), this );
-    action->setToolTip( "Make a (printable) hardcopy of the display" );
-    connect( action, &QAction::triggered, [this]() {
+    action = new QAction( iconFont->icon( fa::clone, colorMap ), tr( "Hardcopy" ), this );
+    action->setToolTip( "Make an immediate (printable) hardcopy of the display" );
+    connect( action, &QAction::triggered, [ this ]() {
         dsoWidget->switchToPrintColors();
-        QTimer::singleShot( 20, [this]() { screenShot( HARDCOPY ); } );
+        QTimer::singleShot( 20, [ this ]() { screenShot( HARDCOPY, true ); } );
+    } );
+    ui->menuExport->addAction( action );
+
+    ui->menuExport->addSeparator();
+
+    action = new QAction( iconFont->icon( fa::camera, colorMap ), tr( "Screenshot .." ), this );
+    action->setToolTip( "Make a screenshot of the program window" );
+    connect( action, &QAction::triggered, [ this ]() { screenShot( SCREENSHOT ); } );
+    ui->menuExport->addAction( action );
+
+    action = new QAction( iconFont->icon( fa::clone, colorMap ), tr( "Hardcopy .." ), this );
+    action->setToolTip( "Make a (printable) hardcopy of the display" );
+    connect( action, &QAction::triggered, [ this ]() {
+        dsoWidget->switchToPrintColors();
+        QTimer::singleShot( 20, [ this ]() { screenShot( HARDCOPY ); } );
     } );
     ui->menuExport->addAction( action );
 
     action = new QAction( iconFont->icon( fa::print, colorMap ), tr( "Print screen .." ), this );
     action->setToolTip( "Send the hardcopy to the printer" );
-    connect( action, &QAction::triggered, [this]() {
+    connect( action, &QAction::triggered, [ this ]() {
         dsoWidget->switchToPrintColors();
-        QTimer::singleShot( 20, [this]() { screenShot( PRINTER ); } );
+        QTimer::singleShot( 20, [ this ]() { screenShot( PRINTER ); } );
     } );
     ui->menuExport->addAction( action );
 
@@ -114,10 +133,10 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
 
     for ( auto *exporter : *exporterRegistry ) {
         action = new QAction( iconFont->icon( exporter->faIcon(), colorMap ), exporter->name(), this );
-        action->setCheckable( exporter->type() == ExporterInterface::Type::ContinousExport );
-        connect( action, &QAction::triggered, [exporter, exporterRegistry]( bool checked ) {
+        action->setCheckable( exporter->type() == ExporterInterface::Type::ContinuousExport );
+        connect( action, &QAction::triggered, [ exporter, exporterRegistry ]( bool checked ) {
             exporterRegistry->setExporterEnabled( exporter,
-                                                  exporter->type() == ExporterInterface::Type::ContinousExport ? checked : true );
+                                                  exporter->type() == ExporterInterface::Type::ContinuousExport ? checked : true );
         } );
         ui->menuExport->addAction( action );
     }
@@ -153,13 +172,13 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
 
     statusBar()->addPermanentWidget( commandEdit, 1 );
 
-    connect( ui->actionManualCommand, &QAction::toggled, [this]( bool checked ) {
+    connect( ui->actionManualCommand, &QAction::toggled, [ this ]( bool checked ) {
         commandEdit->setVisible( checked );
         if ( checked )
             commandEdit->setFocus();
     } );
 
-    connect( commandEdit, &QLineEdit::returnPressed, [this, dsoControl]() {
+    connect( commandEdit, &QLineEdit::returnPressed, [ this, dsoControl ]() {
         Dso::ErrorCode errorCode = dsoControl->stringCommand( commandEdit->text() );
         commandEdit->clear();
         this->ui->actionManualCommand->setChecked( false );
@@ -171,17 +190,17 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     connect( dsoControl, &HantekDsoControl::statusMessage, statusBar(), &QStatusBar::showMessage );
 
     // Connect signals to DSO controller and widget
-    connect( horizontalDock, &HorizontalDock::samplerateChanged, [dsoControl, this]() {
+    connect( horizontalDock, &HorizontalDock::samplerateChanged, [ dsoControl, this ]() {
         dsoControl->setSamplerate( dsoSettings->scope.horizontal.samplerate );
         this->dsoWidget->updateSamplerate( dsoSettings->scope.horizontal.samplerate );
     } );
-    connect( horizontalDock, &HorizontalDock::timebaseChanged, [dsoControl, this]() {
+    connect( horizontalDock, &HorizontalDock::timebaseChanged, [ dsoControl, this ]() {
         dsoControl->setRecordTime( dsoSettings->scope.horizontal.timebase * DIVS_TIME );
         this->dsoWidget->updateTimebase( dsoSettings->scope.horizontal.timebase );
     } );
     connect( spectrumDock, &SpectrumDock::frequencybaseChanged,
-             [this]( double frequencybase ) { this->dsoWidget->updateFrequencybase( frequencybase ); } );
-    connect( dsoControl, &HantekDsoControl::samplerateChanged, [this, horizontalDock, spectrumDock]( double samplerate ) {
+             [ this ]( double frequencybase ) { this->dsoWidget->updateFrequencybase( frequencybase ); } );
+    connect( dsoControl, &HantekDsoControl::samplerateChanged, [ this, horizontalDock, spectrumDock ]( double samplerate ) {
         // The timebase was set, let's adapt the samplerate accordingly
         // printf( "mainwindow::samplerateChanged( %g )\n", samplerate );
         dsoSettings->scope.horizontal.samplerate = samplerate;
@@ -190,18 +209,18 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
         dsoWidget->updateSamplerate( samplerate );
     } );
     connect( horizontalDock, &HorizontalDock::calfreqChanged,
-             [dsoControl, this]() { dsoControl->setCalFreq( dsoSettings->scope.horizontal.calfreq ); } );
-    connect( horizontalDock, &HorizontalDock::formatChanged, [=]( Dso::GraphFormat format ) {
+             [ dsoControl, this ]() { dsoControl->setCalFreq( dsoSettings->scope.horizontal.calfreq ); } );
+    connect( horizontalDock, &HorizontalDock::formatChanged, [ = ]( Dso::GraphFormat format ) {
         ui->actionHistogram->setEnabled( format == Dso::GraphFormat::TY );
         spectrumDock->enableSpectrum( format == Dso::GraphFormat::TY );
     } );
 
     connect( triggerDock, &TriggerDock::modeChanged, dsoControl, &HantekDsoControl::setTriggerMode );
     connect( triggerDock, &TriggerDock::modeChanged, dsoWidget, &DsoWidget::updateTriggerMode );
-    connect( triggerDock, &TriggerDock::modeChanged, [this]( Dso::TriggerMode mode ) {
+    connect( triggerDock, &TriggerDock::modeChanged, [ this ]( Dso::TriggerMode mode ) {
         ui->actionRefresh->setEnabled( Dso::TriggerMode::ROLL == mode && dsoSettings->scope.horizontal.samplerate < 10e3 );
     } );
-    connect( dsoControl, &HantekDsoControl::samplerateChanged, [this]( double samplerate ) {
+    connect( dsoControl, &HantekDsoControl::samplerateChanged, [ this ]( double samplerate ) {
         ui->actionRefresh->setEnabled( Dso::TriggerMode::ROLL == dsoSettings->scope.trigger.mode && samplerate < 10e3 );
     } );
     connect( triggerDock, &TriggerDock::sourceChanged, dsoControl, &HantekDsoControl::setTriggerSource );
@@ -210,10 +229,10 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     // should we send the smooth mode also to dsoWidget?
     connect( triggerDock, &TriggerDock::slopeChanged, dsoControl, &HantekDsoControl::setTriggerSlope );
     connect( triggerDock, &TriggerDock::slopeChanged, dsoWidget, &DsoWidget::updateTriggerSlope );
-    connect( dsoWidget, &DsoWidget::triggerPositionChanged, dsoControl, &HantekDsoControl::setTriggerOffset );
+    connect( dsoWidget, &DsoWidget::triggerPositionChanged, dsoControl, &HantekDsoControl::setTriggerPosition );
     connect( dsoWidget, &DsoWidget::triggerLevelChanged, dsoControl, &HantekDsoControl::setTriggerLevel );
 
-    auto usedChanged = [this, dsoControl, spec]( ChannelID channel ) {
+    auto usedChanged = [ this, dsoControl, spec ]( ChannelID channel ) {
         if ( channel >= dsoSettings->scope.voltage.size() )
             return;
 
@@ -232,23 +251,23 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     connect( spectrumDock, &SpectrumDock::usedChanged, usedChanged );
 
     connect( voltageDock, &VoltageDock::modeChanged, dsoWidget, &DsoWidget::updateMathMode );
-    connect( voltageDock, &VoltageDock::gainChanged, [dsoControl, spec]( ChannelID channel, double gain ) {
+    connect( voltageDock, &VoltageDock::gainChanged, [ dsoControl, spec ]( ChannelID channel, double gain ) {
         if ( channel >= spec->channels )
             return;
         dsoControl->setGain( channel, gain );
     } );
-    connect( voltageDock, &VoltageDock::probeAttnChanged, [dsoControl, spec]( ChannelID channel, double probeAttn ) {
+    connect( voltageDock, &VoltageDock::probeAttnChanged, [ dsoControl, spec ]( ChannelID channel, double probeAttn ) {
         if ( channel >= spec->channels )
             return;
         dsoControl->setProbe( channel, probeAttn );
     } );
-    connect( voltageDock, &VoltageDock::invertedChanged, [dsoControl, spec]( ChannelID channel, bool inverted ) {
+    connect( voltageDock, &VoltageDock::invertedChanged, [ dsoControl, spec ]( ChannelID channel, bool inverted ) {
         if ( channel >= spec->channels )
             return;
         dsoControl->setChannelInverted( channel, inverted );
     } );
     connect( voltageDock, &VoltageDock::couplingChanged, dsoWidget, &DsoWidget::updateVoltageCoupling );
-    connect( voltageDock, &VoltageDock::couplingChanged, [dsoControl, spec]( ChannelID channel, Dso::Coupling coupling ) {
+    connect( voltageDock, &VoltageDock::couplingChanged, [ dsoControl, spec ]( ChannelID channel, Dso::Coupling coupling ) {
         if ( channel >= spec->channels )
             return;
         dsoControl->setCoupling( channel, coupling );
@@ -259,7 +278,7 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     connect( spectrumDock, &SpectrumDock::magnitudeChanged, dsoWidget, &DsoWidget::updateSpectrumMagnitude );
 
     // Started/stopped signals from oscilloscope
-    connect( dsoControl, &HantekDsoControl::samplingStatusChanged, [this]( bool enabled ) {
+    connect( dsoControl, &HantekDsoControl::samplingStatusChanged, this, [ this ]( bool enabled ) {
         QSignalBlocker blocker( this->ui->actionSampling );
         if ( enabled ) {
             this->ui->actionSampling->setIcon( this->iconPause );
@@ -288,8 +307,9 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     connect( this, &MainWindow::settingsLoaded, dsoControl, &HantekDsoControl::applySettings );
     connect( this, &MainWindow::settingsLoaded, dsoWidget, &DsoWidget::updateSlidersSettings );
 
-    connect( ui->actionOpen, &QAction::triggered, [this, spec]() {
-        QString fileName = QFileDialog::getOpenFileName( this, tr( "Open file" ), "", tr( "Settings (*.conf)" ) );
+    connect( ui->actionOpen, &QAction::triggered, [ this, spec ]() {
+        QString fileName = QFileDialog::getOpenFileName( this, tr( "Open file" ), "", tr( "Settings (*.conf)" ), nullptr,
+                                                         QFileDialog::DontUseNativeDialog );
         if ( !fileName.isEmpty() ) {
             if ( dsoSettings->setFilename( fileName ) ) {
                 dsoSettings->load();
@@ -305,14 +325,15 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
         }
     } );
 
-    connect( ui->actionSave, &QAction::triggered, [this]() {
+    connect( ui->actionSave, &QAction::triggered, [ this ]() {
         dsoSettings->mainWindowGeometry = saveGeometry();
         dsoSettings->mainWindowState = saveState();
         dsoSettings->save();
     } );
 
-    connect( ui->actionSave_as, &QAction::triggered, [this]() {
-        QString fileName = QFileDialog::getSaveFileName( this, tr( "Save settings" ), "", tr( "Settings (*.conf)" ) );
+    connect( ui->actionSave_as, &QAction::triggered, [ this ]() {
+        QString fileName = QFileDialog::getSaveFileName( this, tr( "Save settings" ), "", tr( "Settings (*.conf)" ), nullptr,
+                                                         QFileDialog::DontUseNativeDialog );
         if ( fileName.isEmpty() )
             return;
         if ( !fileName.endsWith( ".conf" ) )
@@ -325,7 +346,7 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
 
     connect( ui->actionExit, &QAction::triggered, this, &QWidget::close );
 
-    connect( ui->actionSettings, &QAction::triggered, [this]() {
+    connect( ui->actionSettings, &QAction::triggered, [ this ]() {
         dsoSettings->mainWindowGeometry = saveGeometry();
         dsoSettings->mainWindowState = saveState();
 
@@ -334,7 +355,7 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
         configDialog->show();
     } );
 
-    connect( this->ui->actionPhosphor, &QAction::toggled, [this]( bool enabled ) {
+    connect( this->ui->actionPhosphor, &QAction::toggled, [ this ]( bool enabled ) {
         dsoSettings->view.digitalPhosphor = enabled;
 
         if ( dsoSettings->view.digitalPhosphor )
@@ -344,7 +365,7 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     } );
     this->ui->actionPhosphor->setChecked( dsoSettings->view.digitalPhosphor );
 
-    connect( ui->actionHistogram, &QAction::toggled, [this]( bool enabled ) {
+    connect( ui->actionHistogram, &QAction::toggled, [ this ]( bool enabled ) {
         dsoSettings->scope.histogram = enabled;
 
         if ( dsoSettings->scope.histogram )
@@ -355,7 +376,7 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     ui->actionHistogram->setChecked( dsoSettings->scope.histogram );
     ui->actionHistogram->setEnabled( scope->horizontal.format == Dso::GraphFormat::TY );
 
-    connect( ui->actionZoom, &QAction::toggled, [this]( bool enabled ) {
+    connect( ui->actionZoom, &QAction::toggled, [ this ]( bool enabled ) {
         dsoSettings->view.zoom = enabled;
 
         if ( dsoSettings->view.zoom )
@@ -367,7 +388,7 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
     } );
     ui->actionZoom->setChecked( dsoSettings->view.zoom );
 
-    connect( ui->actionMeasure, &QAction::toggled, [this]( bool enabled ) {
+    connect( ui->actionMeasure, &QAction::toggled, [ this ]( bool enabled ) {
         dsoSettings->view.cursorsVisible = enabled;
 
         if ( dsoSettings->view.cursorsVisible )
@@ -386,7 +407,7 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
             QDesktopServices::openUrl( QUrl( "file://" + usrManualPath ) );
         else
             QDesktopServices::openUrl(
-                QUrl( "https://github.com/OpenHantek/OpenHantek6022/blob/master/docs/OpenHantek6022_User_Manual.pdf" ) );
+                QUrl( "https://github.com/OpenHantek/OpenHantek6022/blob/main/docs/OpenHantek6022_User_Manual.pdf" ) );
     } );
 
     connect( ui->actionACmodification, &QAction::triggered, []() {
@@ -396,47 +417,75 @@ MainWindow::MainWindow( HantekDsoControl *dsoControl, DsoSettings *settings, Exp
             QDesktopServices::openUrl( QUrl( "file://" + ACmodPath ) );
         else
             QDesktopServices::openUrl(
-                QUrl( "https://github.com/OpenHantek/OpenHantek6022/blob/master/docs/HANTEK6022_AC_Modification.pdf" ) );
+                QUrl( "https://github.com/OpenHantek/OpenHantek6022/blob/main/docs/HANTEK6022_AC_Modification.pdf" ) );
     } );
 
-    connect( ui->actionAbout, &QAction::triggered, [this]() {
+    connect( ui->actionAbout, &QAction::triggered, [ this ]() {
         QMessageBox::about(
-            this, tr( "About OpenHantek6022 (%1)" ).arg( VERSION ),
-            tr( "<p>Open source software for Hantek6022 USB oscilloscopes</p>"
-                "<p>Maintainer: Martin Homuth-Rosemann</p>"
-                "<p>Copyright &copy; 2010, 2011 Oliver Haag</p>"
-                "<p>Copyright &copy; 2012-2020 OpenHantek community<br/>"
-                "<a href='https://github.com/OpenHantek'>https://github.com/OpenHantek</a></p>"
-                "<p>Open source firmware copyright &copy; 2019-2020 Ho-Ro<br/>"
-                "<a href='https://github.com/Ho-Ro/Hantek6022API'>https://github.com/Ho-Ro/Hantek6022API</a></p>" ) +
+            this, QString( "OpenHantek6022 (%1)" ).arg( VERSION ),
+            QString( "<p>Open source software for Hantek6022 USB oscilloscopes</p>"
+                     "<p>Maintainer: Martin Homuth-Rosemann</p>"
+                     "<p>Copyright &copy; 2010, 2011 Oliver Haag</p>"
+                     "<p>Copyright &copy; 2012-2021 OpenHantek community<br/>"
+                     "<a href='https://github.com/OpenHantek'>https://github.com/OpenHantek</a></p>"
+                     "<p>Open source firmware copyright &copy; 2019-2021 Ho-Ro<br/>"
+                     "<a href='https://github.com/Ho-Ro/Hantek6022API'>https://github.com/Ho-Ro/Hantek6022API</a></p>"
+                     "<p>Device: %1 (%2), FW%3</p><p>Graphic: %4 - GLSL version %5</p>"
+                     "<p>Qt version: %6</p>" )
+                    .arg( this->dsoSettings->deviceName, this->dsoSettings->deviceID ) // device type, ser. num
+                    .arg( this->dsoSettings->deviceFW, 4, 16, QChar( '0' ) )           // FW version
+                    .arg( GlScope::getOpenGLversion(), GlScope::getGLSLversion() )     // graphic info
+                    .arg( QT_VERSION_STR ) +                                           // Qt version info
                 tr( "<p>Running since %1 seconds.</p>" ).arg( elapsedTime.elapsed() / 1000 ) );
     } );
 
-    emit settingsLoaded( &dsoSettings->scope, spec );
+    emit settingsLoaded( &dsoSettings->scope, spec ); // trigger the previously connected docks, widgets, etc.
 
     dsoWidget->updateTimebase( dsoSettings->scope.horizontal.timebase );
 
     for ( ChannelID channel = 0; channel < spec->channels; ++channel ) {
-        this->dsoWidget->updateVoltageUsed( channel, dsoSettings->scope.voltage[ channel ].used );
-        this->dsoWidget->updateSpectrumUsed( channel, dsoSettings->scope.spectrum[ channel ].used );
+        dsoWidget->updateVoltageUsed( channel, dsoSettings->scope.voltage[ channel ].used );
+        dsoWidget->updateSpectrumUsed( channel, dsoSettings->scope.spectrum[ channel ].used );
     }
 }
 
-MainWindow::~MainWindow() { delete ui; }
 
-void MainWindow::showNewData( std::shared_ptr< PPresult > newData ) { dsoWidget->showNew( newData ); }
+MainWindow::~MainWindow() {
+    if ( dsoSettings->scope.verboseLevel > 1 )
+        qDebug() << " MainWindow::~MainWindow()";
+    delete ui;
+}
+
+
+void MainWindow::showNewData( std::shared_ptr< PPresult > newData ) {
+    if ( dsoSettings->scope.verboseLevel > 5 )
+        qDebug() << "     MainWindow::showNewData()" << newData->tag;
+    dsoWidget->showNew( newData );
+}
+
 
 void MainWindow::exporterStatusChanged( const QString &exporterName, const QString &status ) {
+    if ( dsoSettings->scope.verboseLevel > 3 )
+        qDebug() << "   MainWindow::exporterStatusChanged()" << exporterName << status;
     ui->statusbar->showMessage( tr( "%1: %2" ).arg( exporterName, status ) );
 }
 
-void MainWindow::exporterProgressChanged() { exporterRegistry->checkForWaitingExporters(); }
+
+void MainWindow::exporterProgressChanged() {
+    if ( dsoSettings->scope.verboseLevel > 3 )
+        qDebug() << "   MainWindow::exporterProgressChanged()";
+    exporterRegistry->checkForWaitingExporters();
+}
+
 
 // make screenshot (type == SCREENSHOT) from the complete program window with screen colors ...
 // ... or a printable hardcopy (type == HARDCOPY) from the scope widget only ...
 // ... with printer colors and scaled to double height for zoomed screens ...
 // ... or send this hardcopy directly to the printer (type == PRINTER).
-void MainWindow::screenShot( screenshotType_t screenshotType ) {
+// autoSafe == true -> do not ask for filename, save as PNG with default name into active directory
+void MainWindow::screenShot( screenshotType_t screenshotType, bool autoSafe ) {
+    if ( dsoSettings->scope.verboseLevel > 2 )
+        qDebug() << "  MainWindow::screenShot()" << screenshotType << autoSafe;
     auto activeWindow = screenshotType == SCREENSHOT ? qApp->activeWindow() : dsoWidget;
     QPixmap screenshot( activeWindow->size() );
     QDateTime now = QDateTime::currentDateTime();
@@ -460,17 +509,26 @@ void MainWindow::screenShot( screenshotType_t screenshotType ) {
 #if ( QT_VERSION >= QT_VERSION_CHECK( 5, 10, 0 ) )
     printer.setPdfVersion( QPrinter::PdfVersion_A1b );
 #endif
-    printer.setPaperSize( QPrinter::A4 );
-    printer.setPageMargins( 20, 20, 20, 20, QPrinter::Millimeter );
-    printer.setOrientation( sw > sh ? QPrinter::Landscape : QPrinter::Portrait );
+#if ( QT_VERSION >= QT_VERSION_CHECK( 5, 15, 0 ) )
+    printer.setPageSize( QPageSize( QPageSize::A4 ) );
+#else
+    printer.setPageSize( QPrinter::A4 );
+#endif
+    printer.setPageMargins( QMarginsF( 20, 20, 20, 20 ), QPageLayout::Millimeter );
+    printer.setPageOrientation( sw > sh ? QPageLayout::Landscape : QPageLayout::Portrait );
     printer.setCreator( QCoreApplication::applicationName() );
     printer.setDocName( docName );
 
-    if ( screenshotType != PRINTER ) { // ask for a filename
+    if ( screenshotType != PRINTER ) { // save under filename
         QStringList filters;
         fileName += ".png";
+        if ( autoSafe ) { // save under default name as PNG without asking
+            screenshot.save( fileName );
+            return;
+        }
         filters << tr( "Image (*.png *.jpg)" ) << tr( "Portable Document Format (*.pdf)" );
         QFileDialog fileDialog( this, tr( "Save screenshot" ), fileName, filters.join( ";;" ) );
+        fileDialog.setOption( QFileDialog::DontUseNativeDialog );
         fileDialog.setAcceptMode( QFileDialog::AcceptSave );
         if ( fileDialog.exec() != QDialog::Accepted )
             return;
@@ -487,14 +545,14 @@ void MainWindow::screenShot( screenshotType_t screenshotType ) {
         // supports screen resolution up to about 9600 x 9600 pixel
         int resolution = 75;
         printer.setResolution( resolution );
-        int pw = printer.pageRect().width();
-        int ph = printer.pageRect().height();
+        int pw = printer.pageLayout().paintRectPixels( resolution ).width();
+        int ph = printer.pageLayout().paintRectPixels( resolution ).height();
         int scale = qMin( pw / sw, ph / sh );
         while ( scale < 2 && resolution < 1200 ) {
             resolution *= 2;
             printer.setResolution( resolution );
-            pw = printer.pageRect().width();
-            ph = printer.pageRect().height();
+            pw = printer.pageLayout().paintRectPixels( resolution ).width();
+            ph = printer.pageLayout().paintRectPixels( resolution ).height();
             scale = qMin( pw / sw, ph / sh );
         }
     } else { // Show the printing dialog
@@ -506,8 +564,9 @@ void MainWindow::screenShot( screenshotType_t screenshotType ) {
         }
     }
     // send the pixmap to *.pdf or printer
-    int pw = printer.pageRect().width();
-    int ph = printer.pageRect().height();
+    int pw = printer.pageLayout().paintRectPixels( printer.resolution() ).width();
+    int ph = printer.pageLayout().paintRectPixels( printer.resolution() ).height();
+
     int scale = qMin( pw / sw, ph / sh );
 
     // qDebug() << sw << sh << pw << ph << scale << resolution;
@@ -521,9 +580,12 @@ void MainWindow::screenShot( screenshotType_t screenshotType ) {
     p.end();
 }
 
+
 /// \brief Save the settings before exiting.
 /// \param event The close event that should be handled.
 void MainWindow::closeEvent( QCloseEvent *event ) {
+    if ( dsoSettings->scope.verboseLevel > 2 )
+        qDebug() << "  MainWindow::closeEvent()";
     if ( dsoSettings->alwaysSave ) {
         dsoSettings->mainWindowGeometry = saveGeometry();
         dsoSettings->mainWindowState = saveState();
